@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-# (C) John Mair (banisterfiend) 2016
+# (C) John Mair (banisterfiend) 2010
 # MIT License
 
 require 'pry/version'
@@ -13,7 +13,6 @@ require 'pry/helpers'
 
 require 'pry/basic_object'
 require 'pry/prompt'
-require 'pry/plugins'
 require 'pry/code_object'
 require 'pry/exceptions'
 require 'pry/hooks'
@@ -35,6 +34,7 @@ require 'pry/env'
 
 Pry::Commands = Pry::CommandSet.new unless defined?(Pry::Commands)
 
+require 'pry/commands/ls/config'
 require 'pry/commands/ls/jruby_hacks'
 require 'pry/commands/ls/methods_helper'
 require 'pry/commands/ls/interrogatable'
@@ -58,6 +58,8 @@ require 'pry/config/memoized_value'
 require 'pry/config/lazy_value'
 require 'pry/config'
 
+require 'pry/input/simple_stdio'
+
 require 'pry/pry_class'
 require 'pry/pry_instance'
 require 'pry/inspector'
