@@ -359,7 +359,7 @@ class Pry
     # @return [Fixnum, nil] The line of code in `source_file` which begins
     #   the method's definition, or `nil` if that information is unavailable.
     def source_line
-      source_location.nil? ? nil : source_location.last
+      source_location.nil? ? nil : source_location[1]
     end
 
     # @return [Range, nil] The range of lines in `source_file` which contain
@@ -530,8 +530,9 @@ class Pry
       else
         fail_msg = "Cannot locate this method: #{name}."
         if Helpers::Platform.mri?
-          fail_msg += " Invoke the 'gem-install pry-doc' Pry command to get " \
-                      "access to Ruby Core documentation.\n"
+          fail_msg += " Run `gem install pry-doc` to install" \
+                      " Ruby Core documentation," \
+                      " and `require 'pry-doc'` to load it.\n"
         end
         raise CommandError, fail_msg
       end
@@ -563,8 +564,7 @@ class Pry
     def method_name_from_first_line(first_ln)
       return nil if first_ln.strip !~ /^def /
 
-      tokens = SyntaxHighlighter.tokenize(first_ln)
-      tokens = tokens.tokens.each_slice(2) if tokens.respond_to?(:tokens)
+      tokens = SyntaxHighlighter.tokenize(first_ln).each_slice(2)
       tokens.each_cons(2) do |t1, t2|
         if t2.last == :method || t2.last == :ident && t1 == [".", :operator]
           return t2.first
